@@ -2,7 +2,6 @@
 # Copyright (C) 2020 IHS Markit.
 # All Rights Reserved
 #
-import os
 import warnings
 import os
 
@@ -15,7 +14,13 @@ warnings.filterwarnings(
     'ignore', module="dli", category=ResourceWarning
 )
 
-__version__ = '1.9.0'
+warnings.filterwarnings(
+    action='ignore',
+    category=FutureWarning,
+    message='^pandas.util.testing is deprecated'
+)
+
+__version__ = '1.10.0'
 __product__ = "ihsm-datalake"
 
 
@@ -40,7 +45,7 @@ def connect(
     root_url="https://catalogue.datalake.ihsmarkit.com/__api",
     host=None,
     debug=None,
-    strict=None,
+    strict=True,
     use_keyring=True,
     log_level=None,
 ):
