@@ -1,3 +1,7 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
 import copy
 import os
 import json
@@ -37,8 +41,7 @@ class DatasetBuilder:
     :param str has_datafile_monitoring: Optional. Notify when latest instance is missing
 
     # XXX
-    :param str data_preview_type: Optional enum of NONE STATIC LIVE. 'NONE' means there is no datapreview. STATIC means
-                        to use the file provided. LIVE means to use the latest datafile.
+    :param str data_preview_type: Optional enum of NONE STATIC LIVE. 'NONE' means there is no datapreview. STATIC means to use the file provided. LIVE means to use the latest datafile.
     :param file sample_data: Optional file. File like object. Used in conjuntion with data_preview_type.
     """
 
