@@ -1,13 +1,19 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
+import logging
 import warnings
 
 from dli.client.builders import DatasetBuilder
-from dli.client.components import SirenComponent
+from dli.client.components import SirenComponent, SirenAdapterResponse
+from dli.client.exceptions import CatalogueEntityNotFoundException
 from dli.client.utils import ensure_count_is_valid
-from dli.models.dictionary import DictionaryModel
+from dli.models.dictionary_model import DictionaryModel
 from dli.siren import siren_to_entity
 
-from dli.client.components.urls import dataset_urls, consumption_urls
-
+from dli.client.components.urls import dataset_urls, consumption_urls, \
+    package_urls
 
 class Dataset(SirenComponent):
 
@@ -29,13 +35,15 @@ class Dataset(SirenComponent):
                 # access_key(access_key_id='39D19A440AFE452B9', secret_access_key='F426A93CDECE45C9BFF8F4F19DA5CB81', session_token='C0CC405803F244CA99999')
 
         """
+
+
         payload = {"datasetIds": list(dataset_ids)}
 
         response = self.session.post(
             dataset_urls.access_keys, json=payload
         )
 
-        return siren_to_entity(response.to_siren())
+        return siren_to_entity(SirenAdapterResponse(response).to_siren())
 
     def get_dataset_partitions(self, id=None, name=None, package_id=None, package_name=None):
         """
@@ -71,19 +79,18 @@ class Dataset(SirenComponent):
         if name and (package_name or package_id):
             warnings.warn(
                 'Getting a dataset by name, and package name or package ID'
-                'will be deprecated in future. Slugs will replace this.',
+                'will be deprecated in future. Short-code will replace getting by name or ID.',
                 PendingDeprecationWarning
             )
 
             id = self._get_dataset_id_by_name(
-                name=name,
+                dataset_name=name,
                 package_id=package_id,
                 package_name=package_name
             )
 
-        response = self.session.get(
-            consumption_urls.consumption_partitions.format(id=id)
-        )
+        ds = self.get_dataset(id=id)
+        response = ds.partitions()
 
         return response
 
@@ -136,6 +143,13 @@ class Dataset(SirenComponent):
                     dataset_short_code=dataset_short_code
                 ), params={'organisation_short_code': organisation_short_code}
             )
+
+        elif organisation_short_code and not id:
+            # Incidentally dataset ID also works with organisation_short_code
+            # but as it's deprecated it is not recommended for use.
+            raise Exception("Specify the dataset_short_code "
+                            "with the organisation_short_code.")
+
         else:
             warnings.warn(
                 'Getting a dataset by id or name with package name or package ID '
@@ -144,24 +158,51 @@ class Dataset(SirenComponent):
                 'key arguments.',
                 PendingDeprecationWarning
             )
+
             if not id and name and (package_name or package_id):
                 id = self._get_dataset_id_by_name(
-                    name=name,
+                    dataset_name=name,
                     package_id=package_id,
                     package_name=package_name
                 )
+            elif name and not (package_name or package_id):
+                # we have no way to get the ID.
+                raise Exception("Package name or package ID must be provided"
+                                " along with the dataset name in order to"
+                                " retrieve a dataset by name. "
+                                "It is preferable to use "
+                                "dataset_short_code and "
+                                "organisation_short_code.")
+            elif not name and not id:
+                raise Exception("You must provide the dataset_id (id=) or the"
+                                "dataset_name (name=) alongside the "
+                                "package name or package ID.")
 
             response = self.session.get(
-                dataset_urls.v2_instance.format(id=id)
+                dataset_urls.v2_by_id.format(id=id)
             )
 
         return self.Dataset._from_v2_response(response.json())
 
-    def _get_dataset_id_by_name(self, **kwargs):
-        response = self.session.get(dataset_urls.index, params=kwargs)
-        # Getting dataset by name and id needs to implemented in new API
-        dataset_v1 = response.to_siren()
-        return dataset_v1.datasetId
+    def _get_dataset_id_by_name(self, package_id=None,
+                                dataset_name=None,
+                                package_name=None):
+
+        if dataset_name and package_name:
+            params = {"name": package_name}
+
+            p = self.packages(search_term=[f"name={package_name}"])
+            if len(p) == 1:
+                package_id = p[package_name].id
+            else:
+                raise CatalogueEntityNotFoundException("No such package")
+
+        ds = self.datasets(search_term=[f"package_id={package_id}",
+                                        f"name={dataset_name}"])
+        try:
+            return next(iter(ds.values())).id
+        except StopIteration as s:
+            raise Exception(f"No such dataset `{dataset_name}`")
 
     def register_dataset(self, builder: DatasetBuilder):
         """
@@ -183,6 +224,7 @@ class Dataset(SirenComponent):
                 dataset = client.register_dataset(builder)
         """
         mp_encoder = builder.to_multipart_body()
+
         result = self.session.post(
             dataset_urls.v2_index,
             data=mp_encoder,
@@ -266,7 +308,7 @@ class Dataset(SirenComponent):
 
         mp_encoder = builder.to_multipart_body()
         result = self.session.patch(
-            dataset_urls.v2_instance.format(id=dataset_id), data=mp_encoder,
+            dataset_urls.v2_by_id.format(id=dataset_id), data=mp_encoder,
             headers={
                 'Content-Type': mp_encoder.content_type,
                 'Content-Length': str(mp_encoder.len),
@@ -292,7 +334,7 @@ class Dataset(SirenComponent):
 
         """
         self.session.delete(
-            dataset_urls.v2_instance.format(id=dataset_id)
+            dataset_urls.v2_by_id.format(id=dataset_id)
         )
 
     def get_datafiles(self, dataset_id, name_contains=None,
@@ -332,8 +374,10 @@ class Dataset(SirenComponent):
             'page': page,
         }
 
-        return self.session.get(
-            dataset_urls.datafiles.format(id=dataset_id), params=params
+        return SirenAdapterResponse(
+            self.session.get(
+                dataset_urls.datafiles.format(id=dataset_id), params=params
+            )
         ).to_many_siren('datafile')
 
     def get_latest_datafile(self, dataset_id):
@@ -351,8 +395,10 @@ class Dataset(SirenComponent):
 
                 datafile = client.get_latest_datafile(dataset_id)
         """
-        datafile = self.session.get(
-            dataset_urls.latest_datafile.format(id=dataset_id)
+        datafile = SirenAdapterResponse(
+            self.session.get(
+                dataset_urls.latest_datafile.format(id=dataset_id)
+            )
         ).to_siren()
 
         return siren_to_entity(datafile)
@@ -360,13 +406,6 @@ class Dataset(SirenComponent):
 
 class Dictionary(SirenComponent):
 
-    def _register_schema(self, dataset_id, payload):
-        response = self.session.post(
-            dataset_urls.dictionary_index, json={'data': {'attributes': payload}}
-        )
-
-        return DictionaryModel(response.json()['data'], client=self)
-
     def register_dictionary(
         self,
         dataset_id,
@@ -472,99 +511,6 @@ class Dictionary(SirenComponent):
 
         return DictionaryModel(response.json()['data'], client=self)
 
-    def register_spark_schema(
-        self,
-        dataset_id,
-        version,
-        valid_as_of,
-        spark_schema_json,
-        partitions=None,
-        description=None,
-        **kwargs
-    ):
-        """
-        .. deprecated:: 1.1.0
-           Use :func:`dli.client.components.dataset.Dictionary.register_schema` instead.
-
-            Please migrate this function to register_schema. There is no longer an
-            difference in functionality.
-
-            Please migrate this:
-
-                client.register_spark_schema(
-                    '1234',
-                    version='1a',
-                    valid_as_of='2000-01-01',
-                    spark_schema_json={}
-                )
-
-            To:
-
-                client.register_schema(
-                    '1234',
-                    version='1a',
-                    valid_as_of='2000-01-01',
-                    **spark_schema_json
-                )
-
-        Registers dataframe schema for the datalake `dataset` for instances where data ingest pipelines make use of spark.
-
-        :param str dataset_id: Id of the dataset for the schema.
-        :param str version: A user assigned version name/number. It should be unique within the dataset.
-        :param str valid_as_of: The date as of which the schema is active.
-                               Expected format is YYYY-MM-DD.
-        :param dict spark_schema_json: Json schema for the spark dataframe.
-        :param list[dict] partitions: Optional. Non empty list of `Partition` as described below.
-        :param str description: Optional. Description for the schema.
-
-        .. code-block:: python
-
-                # Partition:
-                {
-                    "name": "key1",
-                    "type": "String"
-                }
-
-        :returns: The registered schema.
-
-        - **Sample**
-
-        .. code-block:: python
-
-                # my_spark_dataframe: some spark dataframe with data being published in the data lake
-
-                my_spark_schema_json = my_spark_dataframe.schema.jsonValue()
-
-                my_schema = client.register_spark_schema(
-                    "my-dataset-id",
-                    version='1a',
-                    valid_as_of='2018-10-31',
-                    spark_schema_json=my_spark_schema_json,
-                    description="My schema description"
-                )
-        """
-        warnings.warn(
-            '''
-            `register_spark_schema` is deprecated. Please migrate this
-            function to register_schema. There is no longer an
-            difference in functionality. Please refer the deprecation documentation.
-
-            https://docs.datalake.ihsmarkit.com/api_docs/index.html#dli.client.components.dataset.Dictionary.register_spark_schema
-            ''',
-            DeprecationWarning
-        )
-
-        payload = {
-            'dataset_id': dataset_id,
-            'version': version,
-            'valid_as_of': valid_as_of,
-        }
-
-        payload.update(spark_schema_json)
-        payload.update(kwargs)
-
-        return self.register_dictionary(**payload)
-
     def get_dictionary(self, dataset_id, version=None):
         """
         Looks up dictionary for a dataset by version. In case version is not specified this will fetch dictionary version having the latest valid_as_of date.
@@ -588,23 +534,16 @@ class Dictionary(SirenComponent):
         """
 
         if version:
-            schema_old_api = self.session.get(
-                dataset_urls.schema_instance_version.format(
+            schema = self.session.get(
+                dataset_urls.v2_schema_instance_version.format(
                     id=dataset_id,
                     version=version
                 )
-            ).to_siren()
-
-            schema_id = schema_old_api.schemaId
-
-            schema = self.session.get(
-                dataset_urls.dictionary_instance.format(id=schema_id)
             )
         else:
             schema = self.session.get(
                 dataset_urls.dictionary_by_dataset_lastest.format(
-                    id=dataset_id,
-                    version=version
+                    id=dataset_id
                 )
             )
         json = schema.json()['data']
@@ -693,7 +632,7 @@ class Dictionary(SirenComponent):
                 }
 
         :returns: The updated dictionary.
-        :rtype: dli.models.dictionary.DictionaryModel
+        :rtype: dli.models.dictionary_model.DictionaryModel
 
         - **Sample**
 
@@ -718,63 +657,4 @@ class Dictionary(SirenComponent):
             json={'data': {'attributes': payload}}
         )
 
-        return DictionaryModel(response.json()['data'], client=self)
-
-    def delete_schema(self, *args, **kwargs):
-        """
-        .. deprecated:: 1.1.0
-           Use :func:`dli.client.components.dataset.Dictionary.delete_dictionary` instead.
-        """
-        warnings.warn(
-            '.delete_schema is deprecated. Please use .delete_dictionary',
-            DeprecationWarning
-        )
-
-        return self.delete_dictionary(*args, **kwargs)
-
-    def edit_schema(self, *args, **kwargs):
-        """
-        .. deprecated:: 1.1.0
-           Use :func:`dli.client.components.dataset.Dictionary.edit_dictionary` instead.
-        """
-        warnings.warn(
-            '.edit_schema is deprecated. Please use .edit_dictionary',
-            DeprecationWarning
-        )
-
-        return self.edit_dictionary(*args, **kwargs)
-
-    def get_schema(self, *args, **kwargs):
-        """
-        .. deprecated:: 1.1.0
-           Use :func:`dli.client.components.dataset.Dictionary.get_dictionary` instead.
-        """
-        warnings.warn(
-            '.get_schema is deprecated. Please use .get_dictionary',
-            DeprecationWarning
-        )
-        return self.get_dictionary(*args, **kwargs)
-
-    def get_schemas(self, *args, **kwargs):
-        """
-        .. deprecated:: 1.1.0
-           Use :func:`dli.client.components.dataset.Dictionary.get_dictionaries` instead.
-        """
-        warnings.warn(
-            '.get_schemas is deprecated. Please use .get_dictionaries',
-            DeprecationWarning
-        )
-
-        return self.get_dictionaries(*args, **kwargs)
-
-    def register_schema(self, *args, **kwargs):
-        """
-        .. deprecated:: 1.1.0
-           Use :func:`dli.client.components.dataset.Dictionary.register_dictionary` instead.
-        """
-        warnings.warn(
-            '.register_schema is deprecated. Please use .register_dictionary',
-            DeprecationWarning
-        )
-
-        return self.register_dictionary(*args, **kwargs)
+        return DictionaryModel(response.json()['data'], client=self)
\ No newline at end of file
