@@ -3,15 +3,14 @@
 # All Rights Reserved
 #
 import logging
+import warnings
+
+import requests
 
 from dli.client.components.urls import package_urls
-from dli.client.components import SirenComponent
+from dli.client.components import SirenComponent, SirenAdapterResponse
 from dli.client.exceptions import CatalogueEntityNotFoundException
-from dli.client.utils import ensure_count_is_valid, filter_out_unknown_keys, to_camel_cased_dict
-from dli.models import AttributesDict
-from dli.models.package_model import PackageModel
-from dli.siren import siren_to_dict, siren_to_entity
-from dli.models.dataset_model import DatasetModel
+from dli.client.utils import filter_out_unknown_keys, to_camel_cased_dict
 
 logger = logging.getLogger(__name__)
 
@@ -50,7 +49,15 @@ class Package(SirenComponent):
         Fetches package metadata for an existing package.
 
         :param str id: The id of the package.
-        :param str name: The name of the package.
+        :param str name: The name of the package. We will perform a case
+        sensitive exact match on this name in the database. If you want
+        a non-exact match or a case insensitive match, then please consider
+        using the `packages` call instead with the `search_term` parameter
+        and an `ilike` matcher, for example:
+
+        .. code:: python
+
+            client.packages(search_term='name ilike example')
 
         :returns: A package instance
         :rtype: collections.namedtuple
@@ -68,13 +75,11 @@ class Package(SirenComponent):
                 package = client.get_package(name='my_package')
 
         """
-        if id is not None:
-            return siren_to_entity(self._get_package(package_id=id))
 
-        if name is not None:
-            return siren_to_entity(self._get_package(name=name))
+        if id is None and name is None:
+            raise ValueError("Either package id or name must be specified to look up package")
 
-        raise ValueError("Either package id or name must be specified to look up package")
+        return self._get_package(package_id=id, name=name)
 
     def get_package_datasets(self, package_id, count=100):
         """
@@ -129,6 +134,9 @@ class Package(SirenComponent):
         is_internal_within_organisation=None,
     ):
         """
+        .. deprecated:: 1.11.0
+            Deprecation Warning: retrieving a package (and other CRUD package operations) using SDK get_package will be deprecated in near future (by 2020-09-08). The API should be used instead, full details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.
+
         Submit a request to create a new package in the Data Catalogue.
 
         Packages are parent structures that contain metadata relating
@@ -197,6 +205,12 @@ class Package(SirenComponent):
                     manager_id="334"
                 )
         """
+        warnings.warn(
+            "Deprecation Warning: registering a package (and other CRUD package operations) using SDK "
+            "register_package will be deprecated in near future (by November 2020). The API should be used "
+            "instead, fill details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
+            PendingDeprecationWarning
+        )
 
         self._validate_terms_and_conditions(terms_and_conditions)
 
@@ -270,12 +284,8 @@ class Package(SirenComponent):
 
             result = self.session.post(
                 package_urls.package_index, json=payload
-            ).to_siren()
-            result.id = result.packageId
-
-            return siren_to_entity(
-                result
             )
+            return self._Package._from_v1_response_to_v2(result.json())
 
 
     def edit_package(
@@ -284,6 +294,9 @@ class Package(SirenComponent):
         **kwargs
     ):
         """
+        .. deprecated:: 1.11.0
+           Deprecation Warning: retrieving a package (and other CRUD package operations) using SDK get_package will be deprecated in near future (by 2020-09-08). The API should be used instead, full details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.
+
         Updates one or more fields in a package.
         If keyword argument is not specified field keeps its old value.
         Optional enum and text type fields can be unset by passing ``None``.
@@ -342,6 +355,12 @@ class Package(SirenComponent):
                     description="Updated my package description",
                 )
         """
+        warnings.warn(
+            "Deprecation Warning: editing a package (and other CRUD package operations) using SDK "
+            "edit_package will be deprecated in near future (by November 2020). The API should be used "
+            "instead, fill details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
+            PendingDeprecationWarning
+        )
         fields = filter_out_unknown_keys(to_camel_cased_dict(kwargs),
                                          Package._KNOWN_FIELDS)
         self._validate_fields(fields)
@@ -363,11 +382,13 @@ class Package(SirenComponent):
         result = self.session.put(
             package_urls.package_edit.format(id=package_id), json=package_as_dict
         )
-
-        return siren_to_entity(result.to_siren())
+        return self._Package._from_v1_response_to_v2(result.json())
 
     def delete_package(self, package_id):
         """
+        .. deprecated:: 1.11.0
+           Deprecation Warning: retrieving a package (and other CRUD package operations) using SDK get_package will be deprecated in near future (by 2020-09-08). The API should be used instead, full details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.
+
         Performs deletion of an existing package. This will delete all underlying datasets for the package as well.
 
         :param str package_id: The id of the package to be deleted.
@@ -381,6 +402,12 @@ class Package(SirenComponent):
                 client.delete_package(package_id)
 
         """
+        warnings.warn(
+            "Deprecation Warning: deleting a package (and other CRUD package operations) using SDK "
+            "delete_package will be deprecated in near future (by November 2020). The API should be used "
+            "instead, fill details on how to use API can be found by signing in to 'https://catalogue-uat.datalake.ihsmarkit.com' then opening the page 'https://catalogue-uat.datalake.ihsmarkit.com/__api/v2/swagger?urls.primaryName=packages'.",
+            PendingDeprecationWarning
+        )
         self.session.delete(
             package_urls.package_edit.format(id=package_id)
         )
@@ -424,15 +451,17 @@ class Package(SirenComponent):
     # Private functions
     #
     def _get_package(self, **kwargs):
+        vals = []
 
         if 'package_id' in kwargs:
             vals = self.packages(
                 search_term=[f"id={kwargs['package_id']}"]).values()
-            vals = list(vals)
+
         elif 'name' in kwargs:
             vals = self.packages(
-                search_term=[f"name={kwargs['name']}"]).get(kwargs["name"])
-            vals = [vals]
+                search_term=[f"name={kwargs['name']}"]).values()
+
+        vals = list(vals)
 
         if len(vals) == 1:
             if hasattr(vals[0], "id"):
@@ -440,7 +469,16 @@ class Package(SirenComponent):
 
             return vals[0]
         elif len(vals) < 1:
-            raise CatalogueEntityNotFoundException("No such package")
+            r = requests.Response()
+            r.status_code = 404
+            r.request = (lambda: True)
+            r.request.method = f"Package {kwargs['package_id'] if kwargs.get('package_id') else kwargs['name']}"
+            r.request.url = ""
+            raise CatalogueEntityNotFoundException(
+                message=f"Package "
+                f"{kwargs['package_id'] if kwargs.get('package_id') else kwargs['name']}",
+                response=r
+            )
         else:
             return vals
 
