@@ -56,7 +56,7 @@ def _start_session(
     log_level=None,
 ):
     if log_level is None:
-        log_level = ':error'
+        log_level = 'stderr:info'
     logger = _setup_logging(log_level)
 
     version_check('dli')
@@ -67,18 +67,21 @@ def _start_session(
 
     logger.debug("Checking auth flow")
 
-    if (user is not None and pasw is not None) and api_key is None:
-        logger.debug("Using SAM client credentials authentication flow")
-        return get_client()(root_url, host, debug=debug, strict=strict,
-                            access_id=user, secret_key=pasw, use_keyring=use_keyring)
-    elif (user is None or pasw is None) and api_key is None:
-        logger.debug("Using SAM PKCE web authentication flow")
-        return get_client()(root_url, host, debug=debug, strict=strict, use_keyring=use_keyring)
-    elif api_key is not None:
-        logger.debug("Using API Key authentication flow")
-        if api_key is not None:
+    try:
+        if (user is not None and pasw is not None) and api_key is None:
+            logger.debug("Using SAM client credentials authentication flow")
             return get_client()(root_url, host, debug=debug, strict=strict,
-                                secret_key=api_key, use_keyring=use_keyring)
+                                access_id=user, secret_key=pasw, use_keyring=use_keyring)
+        elif (user is None or pasw is None) and api_key is None:
+            logger.debug("Using SAM PKCE web authentication flow")
+            return get_client()(root_url, host, debug=debug, strict=strict, use_keyring=use_keyring)
+        elif api_key is not None:
+            logger.debug("Using API Key authentication flow")
+            if api_key is not None:
+                return get_client()(root_url, host, debug=debug, strict=strict,
+                                    secret_key=api_key, use_keyring=use_keyring)
+    except SystemExit:
+        return
 
 
 def start_session(*args, **kwargs):
@@ -122,8 +125,6 @@ def start_session(*args, **kwargs):
         `api_key`: please use the basic flow or client credentials.
 
     """
-    __doc__ = _start_session.__doc__
-
     warnings.warn(
         'start_session is deprecated. To create a client: \n\n'
         '\t\timport dli\n'
