@@ -81,6 +81,29 @@ class PackageModel(AttributesDict):
             print(str(p[1]))
 
     def metadata(self):
+        """
+        Once you have selected a package, you can print the metadata
+        (the available fields and values).
+
+        :example:
+
+            .. code-block:: python
+                # Get all packages.
+                >>> packages = client.packages('example package')
+                # Get metadata of the 'example package' package.
+                >>> packages['example package'].metadata()
+
+        :example:
+
+            .. code-block:: python
+                # Get all packages with a name containing the text 'example package'. Filtering
+                # is done on the server side.
+                >>> packages = client.packages('example package')
+                # Get metadata of the 'example package' package.
+                >>> packages['example package'].metadata()
+
+        :return: Prints the metadata.
+        """
         utils.print_model_metadata(self)
 
     def __str__(self):
