@@ -25,6 +25,7 @@ token_data = {
     },
     "tenant_id": "4e27686c-e72a-44f1-a126-f0d2940617d4",
     "organisation_id": "4e27686c-e72a-44f1-a126-f0d2940617d4",
+    "user_id": "4e27686c-e72a-44f1-a126-f0d2940617d4",
   },
   "email": "jim@example.com",
   "email_verified": True,
@@ -46,26 +47,6 @@ class SdkIntegrationTestCase(unittest.TestCase):
 
     aws_account_id = "12345"
 
-    # FIXME
-    # -----
-    # By now we patch the response to return a token we know will authenticate
-    # instead of generating an api key, this isn't ideal as the behaviour is
-    # not exactly the same, but it is good enough by now.
-    def set_s3_client_mock(self):
-        def _upload(_, files, location, tr=None, r=None):
-            result = []
-            for f in files:
-                path = location + os.path.basename(f)
-                self.s3.append(path)
-                result.append({"path": "s3://" + path})
-            return result
-
-        s3_upload = patch('dli.client.s3.Client.upload_files_to_s3', _upload)
-        s3_upload.start()
-
-        # cleanup
-        self.addCleanup(s3_upload.stop)
-
     @patch("dli.client.dli_client.Session._get_auth_key", lambda self: token)
     @patch("dli.client.dli_client.AnalyticsHandler", lambda self: None)
     def setUp(self):
@@ -80,11 +61,25 @@ class SdkIntegrationTestCase(unittest.TestCase):
         self.client = self.create_session()
         self.s3 = []
 
-        # create a fake s3 repo
-        self.set_s3_client_mock()
-        self.register_aws_account(self.aws_account_id)
+        while True:
+            try:
+                #keep sleeping until we can actually register.
+                time.sleep(1)
+                self.register_aws_account(self.aws_account_id)
+                break
+            except:
+                continue
+
         self.s3_client = localstack_helper.get_s3_client()
 
+    def patch_upload_files_to_s3(self, files, location, tr=None, r=None):
+        result = []
+        for f in files:
+            path = location + os.path.basename(f)
+            self.s3.append(path)
+            result.append({"path": "s3://" + path})
+        return result
+
     def get_api_key(self):
         # url = "%s/generate-my-key" % self.root_url
         # payload = {
@@ -112,7 +107,7 @@ class SdkIntegrationTestCase(unittest.TestCase):
             "terms_and_conditions":  "Terms and Conditions"
         }
         payload.update(**kwargs)
-        return self.client.register_package(**payload).package_id
+        return self.client.register_package(**payload).id
 
     def dataset_builder(self, package_id, dataset_name, **kwargs):
         arguments = dict(kwargs)
@@ -174,8 +169,6 @@ class SdkIntegrationTestCase(unittest.TestCase):
             data=json.dumps({
                 "awsAccountId": str(aws_account_id),
                 "awsAccountName": str(aws_account_id),
-                "awsAccessKeyId": None,
-                "awsSecretAccessKey": None,
                 "awsRegion": "eu-west-1",
                 "accountIds": ["datalake-mgmt"],
                 "awsRoleArn": 'arn:aws:iam::000000000001:user/root'
