@@ -1,5 +1,6 @@
 import pytest
 import io
+import uuid
 
 from dli.client import builders
 from dli.client.exceptions import (
@@ -36,10 +37,11 @@ class DatasetTestCase(SdkIntegrationTestCase):
         )
 
         csv.name = 'file/test.csv'
+        dataset_name = f'datapreview-test-{uuid.uuid4()}'
 
         builder = self.dataset_builder(
             package_id=self.package_id,
-            dataset_name='datapreview-test',
+            dataset_name=dataset_name,
             sample_data=csv,
             data_preview_type='STATIC'
         ).with_external_s3_storage(
@@ -82,10 +84,11 @@ class DatasetTestCase(SdkIntegrationTestCase):
         )
 
         csv.name = 'test.csv'
+        dataset_name = f'datapreview-test-{uuid.uuid4()}'
 
         builder = self.dataset_builder(
             package_id=self.package_id,
-            dataset_name='datapreview-test',
+            dataset_name=dataset_name,
             sample_data=csv,
             data_preview_type='STATIC'
         ).with_external_s3_storage(
@@ -117,11 +120,12 @@ class DatasetTestCase(SdkIntegrationTestCase):
         builder = self.builder.with_external_storage(
             location="jdbc://connectionstring:1232/my-db"
         )
-        builder._data.update({'short_code': 'testGetByShortCode'})
+        short_code = f'testGetByShortCode{str(uuid.uuid4())[:8]}'
+        builder._data.update({'short_code': short_code})
         expected = self.client.register_dataset(builder)
 
         dataset_by_short_code = self.client.get_dataset(
-            dataset_short_code='testGetByShortCode'
+            dataset_short_code=short_code
         )
         self.assertEqual(expected.dataset_id, dataset_by_short_code.dataset_id)
 
@@ -150,7 +154,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
         self.assertEqual(expected.dataset_id, dataset_by_id.dataset_id)
 
         # By name and package id
-        dataset_by_name_and_package_id = self.client.get_dataset(name=expected.name, package_id=package.package_id)
+        dataset_by_name_and_package_id = self.client.get_dataset(name=expected.name, package_id=package.id)
         self.assertEqual(expected.dataset_id, dataset_by_name_and_package_id.dataset_id)
 
         # By name and package name
@@ -159,10 +163,34 @@ class DatasetTestCase(SdkIntegrationTestCase):
 
         # By name and package name and package id
         dataset_by_name_and_package_name_and_id = self.client.get_dataset(name=expected.name,
-                                                                          package_id=package.package_id,
+                                                                          package_id=package.id,
                                                                           package_name=package.name)
         self.assertEqual(expected.dataset_id, dataset_by_name_and_package_name_and_id.dataset_id)
 
+        # By bad dataset name, valid package name
+        with self.assertRaises(Exception):
+            dataset_by_baddataset_name = self.client.get_dataset(
+                name="bad name",
+                package_id=package.package_id,
+                package_name=package.name)
+
+        # By dataset name, invalid package name
+        with self.assertRaises(Exception):
+            dataset_by_badpackage_name = self.client.get_dataset(
+                name=expected.name,
+                package_name="bad name")
+
+        # No package deets
+        with self.assertRaises(Exception):
+            dataset_by_name_no_package = self.client.get_dataset(
+                name="bad name")
+
+        # No dataset deets
+        with self.assertRaises(Exception):
+            dataset_by_package_name_no_dataset = self.client.get_dataset(
+                package_name="bad")
+
+
     def test_cannot_get_dataset_by_name_if_package_id_and_package_name_mismatch(self):
         builder = self.builder.with_external_storage(
             location="jdbc://connectionstring:1232/my-db"
@@ -171,7 +199,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
         dataset = self.client.register_dataset(builder)
 
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_dataset(name=dataset.name, package_id=package.package_id, package_name="unknown")
+            self.client.get_dataset(name=dataset.name, package_id=package.id, package_name="unknown")
             self.client.get_dataset(name=dataset.name, package_id="unknown", package_name=package.name)
 
     def test_retrieve_keys_for_unknown_dataset_raises_error(self):
@@ -218,10 +246,13 @@ class DatasetTestCase(SdkIntegrationTestCase):
         self.assertEqual(dataset.location.type, "Other")
 
     def test_can_create_dataset_with_short_code(self):
+
+        dataset_name = f'datapreview-test-{uuid.uuid4()}'
+        short_code = f'someRandomShortCode{str(uuid.uuid4())[:8]}'
         builder = self.dataset_builder(
             package_id=self.package_id,
-            dataset_name='datapreview-test',
-            short_code='someRandomShortCode'
+            dataset_name=dataset_name,
+            short_code=short_code,
         ).with_external_storage(
             location='jdbc://connectionstring:1232/my-db'
         )
@@ -322,6 +353,7 @@ class DatasetTestCase(SdkIntegrationTestCase):
         with self.assertRaises(CatalogueEntityNotFoundException):
             self.client.register_dataset(builder)
 
+
 @pytest.mark.integration
 class DatasetDatafilesTestCase(SdkIntegrationTestCase):
 
@@ -483,9 +515,9 @@ class DatasetSchemasTestCase(SdkIntegrationTestCase):
         payload.update(**kwargs)
         return payload
 
-    def test_cannot_register_schema_for_missing_or_unknown_dataset(self):
+    def test_cannot_register_dictionary_for_missing_or_unknown_dataset(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.register_schema(
+            self.client.register_dictionary(
                 'unknown', version='1a', valid_as_of='2018-10-31', fields=[
                     {
                         'name': 'field2',
@@ -497,7 +529,7 @@ class DatasetSchemasTestCase(SdkIntegrationTestCase):
                     },
                 ])
 
-    def test_cannot_register_schema_with_invalid_payload(self):
+    def test_cannot_register_dictionary_with_invalid_payload(self):
         my_schema_fields = [
             {
                 'name': 'field1',
@@ -507,26 +539,26 @@ class DatasetSchemasTestCase(SdkIntegrationTestCase):
         ]
         # fields cannot be empty or contain invalid field definitions
         with self.assertRaises(InvalidPayloadException):
-            self.client.register_schema(self.dataset_id, version='1a', valid_as_of='2018-10-31', fields=None)
+            self.client.register_dictionary(self.dataset_id, version='1a', valid_as_of='2018-10-31', fields=None)
         with self.assertRaises(InvalidPayloadException):
-            self.client.register_schema(self.dataset_id, version='1a', valid_as_of='2018-10-31',
+            self.client.register_dictionary(self.dataset_id, version='1a', valid_as_of='2018-10-31',
                                         fields=[{'random': 'keys'}])
 
         # valid_as_of should be date in ISO format
         with self.assertRaises(InvalidPayloadException):
-            self.client.register_schema(self.dataset_id, version='1a', valid_as_of='31/10/2018',
+            self.client.register_dictionary(self.dataset_id, version='1a', valid_as_of='31/10/2018',
                                         fields=my_schema_fields)
         with self.assertRaises(InvalidPayloadException):
-            self.client.register_schema(self.dataset_id, version='1a', valid_as_of='halloween', fields=my_schema_fields)
+            self.client.register_dictionary(self.dataset_id, version='1a', valid_as_of='halloween', fields=my_schema_fields)
 
         # partitions if provided can be empty, but must not contain invalid key value pairs
-        self.client.register_schema(self.dataset_id, version='1a', valid_as_of='2018-10-31',
+        self.client.register_dictionary(self.dataset_id, version='1a', valid_as_of='2018-10-31',
                                     fields=my_schema_fields, partitions=[])
         with self.assertRaises(InvalidPayloadException):
-            self.client.register_schema(self.dataset_id, version='1a', valid_as_of='2018-10-31',
+            self.client.register_dictionary(self.dataset_id, version='1a', valid_as_of='2018-10-31',
                                         fields=my_schema_fields, partitions=[{'random': 'keys'}])
 
-    def test_can_register_schema(self):
+    def test_can_register_dictionary(self):
         my_schema_fields = [
             {
                 'name': 'field1',
@@ -556,7 +588,7 @@ class DatasetSchemasTestCase(SdkIntegrationTestCase):
             'description': 'My Funky Schema',
         }
 
-        schema = self.client.register_schema(self.dataset_id, **params)
+        schema = self.client.register_dictionary(self.dataset_id, **params)
         self.assertIsNotNone(schema)
         self.assertEqual(schema.version, params['version'])
         self.assertEqual(schema.valid_as_of, params['valid_as_of'])
@@ -564,49 +596,20 @@ class DatasetSchemasTestCase(SdkIntegrationTestCase):
         self.assertTrue(all([f['name'] in ['field1', 'field2'] for f in schema.fields]))
         self.assertEqual(len(schema.partitions), 1)
 
-    def test_can_register_spark_schema(self):
-        spark_schema = {
-            'fields': [
-                {
-                    'metadata': {},
-                    'name': 'field_1',
-                    'nullable': True,
-                    'type': 'string'
-                },
-                {
-                    'metadata': {},
-                    'name': 'field_2',
-                    'nullable': True,
-                    'type': 'long'
-                }
-            ],
-        }
-        schema = self.client.register_spark_schema(
-            self.dataset_id,
-            version='1a',
-            valid_as_of='2018-10-31',
-            spark_schema_json=spark_schema
-        )
-        self.assertIsNotNone(schema)
-        self.assertEqual(schema.version, '1a')
-        self.assertEqual(schema.valid_as_of, '2018-10-31')
-        self.assertEqual(len(schema.fields), 2)
-        self.assertTrue(all([f['name'] in ['field_1', 'field_2'] for f in schema.fields]))
-
     def test_cannot_get_schema_for_missing_or_unknown_dataset(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schema(None)
+            self.client.get_dictionary(None)
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schema('unknown')
+            self.client.get_dictionary('unknown')
 
     def test_cannot_get_schema_for_dataset_with_no_schemas(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schema(self.dataset_id)
+            self.client.get_dictionary(self.dataset_id)
 
     def test_can_get_schema_by_version(self):
         payload = self.create_schema_payload('1a', '2018-10-31')
-        self.client.register_schema(self.dataset_id, **payload)
-        schema = self.client.get_schema(self.dataset_id, payload['version'])
+        self.client.register_dictionary(self.dataset_id, **payload)
+        schema = self.client.get_dictionary(self.dataset_id, payload['version'])
         self.assertIsNotNone(schema)
         self.assertEqual(schema.version, payload['version'])
         assert schema.fields
@@ -615,87 +618,87 @@ class DatasetSchemasTestCase(SdkIntegrationTestCase):
         payload_a = self.create_schema_payload('1a', '2018-10-31')
         payload_b = self.create_schema_payload('1b', '2018-11-05')
 
-        self.client.register_schema(self.dataset_id, **payload_a)
-        self.client.register_schema(self.dataset_id, **payload_b)
+        self.client.register_dictionary(self.dataset_id, **payload_a)
+        self.client.register_dictionary(self.dataset_id, **payload_b)
 
-        schema = self.client.get_schema(self.dataset_id)
+        schema = self.client.get_dictionary(self.dataset_id)
         self.assertIsNotNone(schema)
         self.assertEqual(schema.version, payload_b['version'])
 
-    def test_cannot_get_schemas_for_missing_or_unknown_dataset(self):
+    def test_cannot_get_dictionaries_for_missing_or_unknown_dataset(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schemas(None)
+            self.client.get_dictionaries(None)
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schemas('unknown')
+            self.client.get_dictionaries('unknown')
 
-    def test_get_schemas_returns_empty_for_dataset_with_no_schemas(self):
-        self.assertEqual(self.client.get_schemas(self.dataset_id), [])
+    def test_get_dictionaries_returns_empty_for_dataset_with_no_schemas(self):
+        self.assertEqual(self.client.get_dictionaries(self.dataset_id), [])
 
-    def test_can_get_schemas_for_dataset_and_schemas_are_sorted_by_valid_as_of_date(self):
+    def test_can_get_dictionaries_for_dataset_and_schemas_are_sorted_by_valid_as_of_date(self):
         payload_a = self.create_schema_payload('1a', '2018-10-31')
         payload_b = self.create_schema_payload('1b', '2018-11-05')
         payload_c = self.create_schema_payload('1c', '2018-11-02')
 
-        self.client.register_schema(self.dataset_id, **payload_a)
-        self.client.register_schema(self.dataset_id, **payload_b)
-        self.client.register_schema(self.dataset_id, **payload_c)
+        self.client.register_dictionary(self.dataset_id, **payload_a)
+        self.client.register_dictionary(self.dataset_id, **payload_b)
+        self.client.register_dictionary(self.dataset_id, **payload_c)
 
-        all_schemas = self.client.get_schemas(self.dataset_id)
+        all_schemas = self.client.get_dictionaries(self.dataset_id)
         self.assertEqual(len(all_schemas), 3)
         self.assertEqual(all_schemas[0].version, payload_b['version'])
 
-        fewer_schemas = self.client.get_schemas(self.dataset_id, count=2)
+        fewer_schemas = self.client.get_dictionaries(self.dataset_id, count=2)
         self.assertEqual(len(fewer_schemas), 2)
         self.assertEqual(fewer_schemas[0].version, payload_b['version'])
 
-    def test_cannot_delete_schema_for_missing_or_unknown_dataset(self):
+    def test_cannot_delete_dictionary_for_missing_or_unknown_dataset(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.delete_schema(None, '1a')
+            self.client.delete_dictionary(None, '1a')
 
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.delete_schema('unknown', '1a')
+            self.client.delete_dictionary('unknown', '1a')
 
-    def test_cannot_delete_schema_if_missing_or_unknown_version(self):
+    def test_cannot_delete_dictionary_if_missing_or_unknown_version(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.delete_schema(self.dataset_id, None)
+            self.client.delete_dictionary(self.dataset_id, None)
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.delete_schema(self.dataset_id, 'unknown')
+            self.client.delete_dictionary(self.dataset_id, 'unknown')
 
-    def test_can_delete_schema_by_version(self):
+    def test_can_delete_dictionary_by_version(self):
         # Create schema first
         payload = self.create_schema_payload('1a', '2018-10-31')
-        self.client.register_schema(self.dataset_id, **payload)
-        self.assertIsNotNone(self.client.get_schema(self.dataset_id, payload['version']))
+        self.client.register_dictionary(self.dataset_id, **payload)
+        self.assertIsNotNone(self.client.get_dictionary(self.dataset_id, payload['version']))
         # Now Delete
-        self.client.delete_schema(self.dataset_id, payload['version'])
+        self.client.delete_dictionary(self.dataset_id, payload['version'])
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schema(self.dataset_id, payload['version'])
+            self.client.get_dictionary(self.dataset_id, payload['version'])
 
-    def test_cannot_edit_schema_for_missing_or_unknown_dataset(self):
+    def test_cannot_edit_dictionary_for_missing_or_unknown_dataset(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.edit_schema(None, '1a')
+            self.client.edit_dictionary(None, '1a')
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.edit_schema('unknown', '1a')
+            self.client.edit_dictionary('unknown', '1a')
 
-    def test_cannot_edit_schema_if_missing_or_unknown_version(self):
+    def test_cannot_edit_dictionary_if_missing_or_unknown_version(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.edit_schema(self.dataset_id, None)
+            self.client.edit_dictionary(self.dataset_id, None)
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.edit_schema(self.dataset_id, 'unknown')
+            self.client.edit_dictionary(self.dataset_id, 'unknown')
 
-    def test_can_edit_schema_by_version(self):
+    def test_can_edit_dictionary_by_version(self):
         # Create schema first
         payload = self.create_schema_payload('1a', '2018-10-31')
-        self.client.register_schema(self.dataset_id, **payload)
-        self.assertIsNotNone(self.client.get_schema(self.dataset_id, payload['version']))
+        self.client.register_dictionary(self.dataset_id, **payload)
+        self.assertIsNotNone(self.client.get_dictionary(self.dataset_id, payload['version']))
         # Now Update valid as of
-        result = self.client.edit_schema(self.dataset_id, payload['version'], valid_as_of='2018-11-05')
+        result = self.client.edit_dictionary(self.dataset_id, payload['version'], valid_as_of='2018-11-05')
 
         self.assertEqual(result.valid_as_of, '2018-11-05')
         # Can update version too if available
-        result = self.client.edit_schema(self.dataset_id, payload['version'], new_version='1b')
+        result = self.client.edit_dictionary(self.dataset_id, payload['version'], new_version='1b')
         self.assertEqual(result.version, '1b')
         # version now updated
         with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_schema(self.dataset_id, payload['version'])
+            self.client.get_dictionary(self.dataset_id, payload['version'])
 
