@@ -46,6 +46,11 @@ def jwt(request):
 
 
 class TestDliClient(DliClient):
+
+    # Disable pytest's attempt to run this class (because it has a name
+    # starting with `Test`). Otherwise you see a pytest warning.
+    __test__ = False
+
     def __init__(self, api_root=None,
                  auth_key=None, host=None,
                  debug=False, jwt=None, secret=None,
