@@ -1,24 +1,21 @@
+import io
+import json
+import os
+import random
+import re
+import tempfile
 from contextlib import redirect_stdout
 from functools import partial
-
-import pytest
-import copy
-import os
-import io
-import pytest
-import tempfile
-import pyarrow
-import pandas
-import numpy
-import random
-import json
-import jwt
-
-from contextlib import redirect_stdout
-from tests.integration.conftest import TestDliClient
-from dli.client.exceptions import DataframeStreamingException, TimeoutException
 from unittest.mock import MagicMock, ANY
 
+import jwt
+import numpy
+import pandas
+import pyarrow
+import pytest
+from dli.client.exceptions import DataframeStreamingException, TimeoutException
+from pyarrow.lib import ArrowInvalid
+from tests.integration.conftest import TestDliClient
 from tests.models.conftest import mock_catalogue_filter_search_response_impl
 
 
@@ -515,7 +512,8 @@ class TestInstanceDataframe:
         writer.write_batch(batch)
         # It's important the IPC stream is closed
         writer.close()
-        return df, io.BytesIO(sink.getvalue().to_pybytes())
+        var = sink.getvalue()
+        return df, io.BytesIO(var)
 
     @pytest.fixture
     def dataset(self, client):
@@ -536,35 +534,24 @@ class TestInstanceDataframe:
         test_dataframe, stream = arrow_ipc_stream
         dataset._client = MagicMock()
         dataset._client._environment.consumption = 'https://test/'
-        dataset._client.session.get().raw = stream
         dataset._client.session.get().status_code = 200
+        msg = json.dumps({
+            'status': 200,
+        }).encode('utf')
+
+        _io_bytesio_seekend = 2
+        stream.seek(0, _io_bytesio_seekend)
+        stream.write(msg)
 
         def _bench():
-            # reset our fake socket
             stream.seek(0)
+            # reset our fake socket
+            dataset._client.session.get().raw = stream
             return dataset.dataframe()
 
         # The benchmark code will run several times to get an average runtime.
         df = benchmark(_bench)
 
-        # Check that we can read from the file that was written.
-        print('test_dataframe')
-        print(test_dataframe.head(4).values)
-        print('df')
-        print(df.head(4).values)
-        pandas.testing.assert_frame_equal(test_dataframe, df)
-
-    @pytest.mark.parametrize('value', ['1', 0])
-    def test_dataframe_nrows_validation(self, client, arrow_ipc_stream,
-                                        value, dataset):
-        test_dataframe, stream = arrow_ipc_stream
-        dataset._client = MagicMock()
-        dataset._client._environment.consumption = 'https://test/'
-        dataset._client.session.get().raw = stream
-        dataset._client.session.get().status_code = 200
-
-        # Expected to pass.
-        df = dataset.dataframe(value)
         # Check that we can read from the file that was written.
         pandas.testing.assert_frame_equal(test_dataframe, df)
 
@@ -607,26 +594,64 @@ class TestInstanceDataframe:
         msg = client.get_dataset_partitions(id=dataset.id)
         assert(msg == partitions["data"]["attributes"]["partitions"])
 
-
-    def test_dataframe_handle_errors(self, client, arrow_ipc_stream,
+    def test_dataframe_handle_errors(self, arrow_ipc_stream,
                                      dataset):
         test_dataframe, stream = arrow_ipc_stream
         error_msg = json.dumps({
             'status': 400,
         }).encode('utf')
 
-        stream.seek(0, 2)
+        _io_bytesio_seekend = 2
+        stream.seek(0, _io_bytesio_seekend)
         stream.write(error_msg)
         stream.seek(0)
 
         dataset._client = MagicMock()
         dataset._client._environment.consumption = 'https://test/'
+
         dataset._client.session.get().raw = stream
         dataset._client.session.get().status_code = 200
 
         with pytest.raises(DataframeStreamingException):
             dataset.dataframe(1)
 
+    def test_dataframe_handle_arrowinvalid_exception(
+            self, arrow_ipc_stream, dataset
+    ):
+        arrow_ipc_stream = io.BytesIO(b'invalid')
+
+        arrow_ipc_stream.seek(0)
+
+        dataset._client = MagicMock()
+        dataset._client._environment.consumption = 'https://test/'
+
+        dataset._client.session.get().raw = arrow_ipc_stream
+        dataset._client.session.get().status_code = 200
+
+        with pytest.raises(ArrowInvalid) as excinfo:
+            dataset.dataframe(1)
+
+        message = r'Sorry, the dataframe you are trying to read is too ' \
+                  'large to fit into memory. Please consider one of these ' \
+                  'alternatives:' \
+                  '\n\n1. Run the same code on a machine that has more ' \
+                  'RAM, for example a Jupyter Notebook hosted on an AWS ' \
+                  'environment.'\
+                  '\n2. Use a big data tool such as Spark, Dask or similar ' \
+                  'to read the data via our S3 proxy. Unlike Pandas, these ' \
+                  'big data tools are able to apply some operations such ' \
+                  'as filtering without having to hold all of the data ' \
+                  'into memory. See https://supportlibrary.ihsmarkit.com/' \
+                  'display/DLSL/Using+the+S3+Proxy+with+Big+Data+tooling' \
+                  '\n\nOriginal exception: '
+
+        error_message = str(excinfo.value)
+        assert error_message.startswith(message)
+
+        pattern = r"Original exception: Expected to read \d+ metadata " \
+                  r"bytes, but only read \d+"
+        assert re.search(pattern, error_message)
+
 
 class TestDatasetModule:
 
